@@ -3,7 +3,7 @@ from numpy import array
 from obspy.core.util.attribdict import AttribDict
 
 from microquake.core.settings import settings
-from microquake.helpers.velocity import get_velocities
+from microquake.core.helpers.velocity import get_velocities
 
 
 def nll_velgrids():
