@@ -1,7 +1,7 @@
 from loguru import logger
 
-from microquake.helpers.hdf5 import write_ttable_h5
-from microquake.helpers.nlloc import nll_velgrids, nll_sensors
+from microquake.core.helpers.hdf5 import write_ttable_h5
+from microquake.core.helpers.nlloc import nll_velgrids, nll_sensors
 from microquake.core.nlloc import NLL
 from microquake.core.settings import settings
 
